@@ -3,13 +3,14 @@ package App::Netdisco::Web::Plugin::Device::Details;
 use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
+use Dancer::Plugin::Auth::Extensible;
 
 use App::Netdisco::Web::Plugin;
 
 register_device_tab({ tag => 'details', label => 'Details' });
 
 # device details table
-ajax '/ajax/content/device/details' => sub {
+ajax '/ajax/content/device/details' => require_login sub {
     my $q = param('q');
     my $device = schema('netdisco')->resultset('Device')
       ->with_times()->search_for_device($q) or send_error('Bad device', 400);
