@@ -23,43 +23,26 @@ sub _get_name {
 }
 
 sub _add_children {
-    my ($ptr, $childs, $step, $limit) = @_;
-
-    return $step if $limit and $step > $limit;
+    my ($ptr, $childs) = @_;
     my @legit = ();
-    my $max = $step;
 
     foreach my $c (@$childs) {
         next if exists var('seen')->{$c};
         var('seen')->{$c}++;
         push @legit, $c;
-        push @{$ptr}, {
-          name => _get_name($c),
-          fullname => (var('devices')->{$c} || $c),
-          ip => $c,
-        };
+        push @{$ptr}, { name => _get_name($c), ip => $c };
     }
 
     for (my $i = 0; $i < @legit; $i++) {
         $ptr->[$i]->{children} = [];
-        my $nm = _add_children($ptr->[$i]->{children}, var('links')->{$legit[$i]},
-          ($step + 1), $limit);
-        $max = $nm if $nm > $max;
+        _add_children($ptr->[$i]->{children}, var('links')->{$legit[$i]});
     }
-
-    return $max;
 }
 
 # d3 seems not to use proper ajax semantics, so get instead of ajax
 get '/ajax/data/device/netmap' => require_login sub {
     my $q = param('q');
 
-    my $vlan = param('vlan');
-    undef $vlan if (defined $vlan and $vlan !~ m/^\d+$/);
-
-    my $depth = (param('depth') || 8);
-    undef $depth if (defined $depth and $depth !~ m/^\d+$/);
-
     my $device = schema('netdisco')->resultset('Device')
       ->search_for_device($q) or send_error('Bad device', 400);
     my $start = $device->ip;
@@ -72,19 +55,9 @@ get '/ajax/data/device/netmap' => require_login sub {
 
     var(links => {});
     my $rs = schema('netdisco')->resultset('Virtual::DeviceLinks')->search({}, {
-      columns => [qw/left_ip right_ip/],
       result_class => 'DBIx::Class::ResultClass::HashRefInflator',
     });
 
-    if ($vlan) {
-        $rs = $rs->search({
-          'left_vlans.vlan' => $vlan,
-          'right_vlans.vlan' => $vlan,
-        }, {
-          join => [qw/left_vlans right_vlans/],
-        });
-    }
-
     while (my $l = $rs->next) {
         var('links')->{ $l->{left_ip} } ||= [];
         push @{ var('links')->{ $l->{left_ip} } }, $l->{right_ip};
@@ -93,13 +66,11 @@ get '/ajax/data/device/netmap' => require_login sub {
     my %tree = (
         ip => $start,
         name => _get_name($start),
-        fullname => (var('devices')->{$start} || $start),
         children => [],
     );
 
     var(seen => {$start => 1});
-    my $max = _add_children($tree{children}, var('links')->{$start}, 1, $depth);
-    $tree{scale} = $max;
+    _add_children($tree{children}, var('links')->{$start});
 
     content_type('application/json');
     to_json(\%tree);
